>From fe3246f4a967f5b305eed639cc2f3c33aac599ac Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Jan=20Urba=C5=84ski?= <wulczer@wulczer.org>
Date: Sun, 2 Jan 2011 11:39:26 +0100
Subject: [PATCH 6/7] Improve exception usage in PL/Python.

Specifically, use the builtin ValueError, not SPIError for errors
having to do with argument counts or types. Use SPIError, not simply
plpy.Error for errors in PLy_spi_execute_plan. Finally, do not set a
Python exception if PyArg_ParseTuple failed, as it arleady sets the
correct exception.
---
 src/pl/plpython/plpython.c |   14 ++++++--------
 1 files changed, 6 insertions(+), 8 deletions(-)

diff --git a/src/pl/plpython/plpython.c b/src/pl/plpython/plpython.c
index 1eeabb0..c07913c 100644
--- a/src/pl/plpython/plpython.c
+++ b/src/pl/plpython/plpython.c
@@ -2844,14 +2844,12 @@ PLy_spi_prepare(PyObject *self, PyObject *args)
 
 	if (!PyArg_ParseTuple(args, "s|O", &query, &list))
 	{
-		PLy_exception_set(PLy_exc_spi_error,
-						  "invalid arguments for plpy.prepare");
 		return NULL;
 	}
 
 	if (list && (!PySequence_Check(list)))
 	{
-		PLy_exception_set(PLy_exc_spi_error,
+		PLy_exception_set(PyExc_ValueError,
 					   "second argument of plpy.prepare must be a sequence");
 		return NULL;
 	}
@@ -3004,7 +3002,7 @@ PLy_spi_execute_plan(PyObject *ob, PyObject *list, long limit)
 	{
 		if (!PySequence_Check(list) || PyString_Check(list) || PyUnicode_Check(list))
 		{
-			PLy_exception_set(PLy_exc_spi_error, "plpy.execute takes a sequence as its second argument");
+			PLy_exception_set(PyExc_ValueError, "plpy.execute takes a sequence as its second argument");
 			return NULL;
 		}
 		nargs = PySequence_Length(list);
@@ -3022,9 +3020,9 @@ PLy_spi_execute_plan(PyObject *ob, PyObject *list, long limit)
 		if (so == NULL)
 			PLy_elog(ERROR, "could not execute plan");
 		sv = PyString_AsString(so);
-		PLy_exception_set_plural(PLy_exc_spi_error,
-							  "Expected sequence of %d argument, got %d: %s",
-							 "Expected sequence of %d arguments, got %d: %s",
+		PLy_exception_set_plural(PyExc_ValueError,
+								 "Expected sequence of %d argument, got %d: %s",
+								 "Expected sequence of %d arguments, got %d: %s",
 								 plan->nargs,
 								 plan->nargs, nargs, sv);
 		Py_DECREF(so);
@@ -3109,7 +3107,7 @@ PLy_spi_execute_plan(PyObject *ob, PyObject *list, long limit)
 		}
 
 		if (!PyErr_Occurred())
-			PLy_exception_set(PLy_exc_error,
+			PLy_exception_set(PLy_exc_spi_error,
 							  "unrecognized error in PLy_spi_execute_plan");
 		PLy_elog(WARNING, NULL);
 		PLy_spi_exception_set(edata);
-- 
1.7.2.3

